@@ -1,9 +1,9 @@
 # -*- coding: utf-8 -*-
 NAME = 'ip2location-python'
 DESCRIPTION = 'ipv4 to location'
-VERSION = '0.1.1'
+VERSION = '0.1.2'
 AUTHOR = 'pengyao'
 AUTHOR_EMAIL = 'pengyao@pengyao.org'
-COPYRIGHT = 'Copyright © 2014 ' + AUTHOR
+COPYRIGHT = 'Copyright © 2015 ' + AUTHOR
 LICENCE = 'Apache License V2.0'
-URL = 'https://github.com/pengyao/ip2location'
+URL = 'https://github.com/pengyao/ip2location-python'
